@@ -403,8 +403,7 @@ class Ppos(Module):
         return receive
 
     def getDelegateReward(self, from_address, node_ids=[]):
-        data = [rlp.encode(int(5100)), rlp.encode(bytes.fromhex(remove_0x_prefix(from_address)))]
-        data = data.append(rlp.encode(node_ids))
+        data = [rlp.encode(int(5100)), rlp.encode(bytes.fromhex(remove_0x_prefix(from_address))), rlp.encode(node_ids)]
         data = rlp.encode(data)
         raw_data = call_obj(self, from_address, self.web3.delegateRewardAddress, data)
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
